import axios from 'axios'

// request 拦截器
const requestInterceptor = config => {
  return config
}

// response 拦截器
const responseInterceptor = response => {
  const { data, headers } = response
  const contentType = headers['Content-Type'] || headers['content-type'] || ''

  if (/json/.test(contentType)) {
    if ('0' === data.code) {
      return data.data
    } else if ('1' === data.code) {
      return Promise.reject('账号未登录或没有权限')
    } else {
      return Promise.reject(data.message)
    }

  } else {
    return Promise.reject("账号未登录或没有权限")
  }
}

// 错误处理
const handleError = type => error => {
  if (error.response) {
    console.error(`[${type}]:`)
    console.error(error.response)    
  } else {
    const errorMessage = error.message || error.msg || error
    console.error(`[${type}] ${errorMessage}`)
    console.error(error)
    return Promise.reject(errorMessage)
  }
}

const request = axios.create({
  // 通用前缀
  baseURL: '/mp',
  // 允许 cookie
  withCredentials: true,
  // 全部都是 post 请求
  method: 'post',
})

request.interceptors.request.use(requestInterceptor, handleError('REQUEST'))
request.interceptors.response.use(responseInterceptor, handleError('RESPONSE'))

export default request
